@@ -345,9 +345,10 @@ panel.superpose <-
     x <- as.numeric(x)
     if (!is.null(y)) y <- as.numeric(y)
 
-    if (length(x)>0) {
-
-        if (!missing(col)) {
+    if (length(x)>0)
+    {
+        if (!missing(col))
+        {
             if (missing(col.line)) col.line <- col
             if (missing(col.symbol)) col.symbol <- col
         }
@@ -374,8 +375,8 @@ panel.superpose <-
             else if (is.character(panel.groups)) get(panel.groups)
             else eval(panel.groups)
 
-        for (i in seq(along=vals)) {
-
+        for (i in seq(along=vals))
+        {
             id <- (groups[subscripts] == vals[i])
             if (any(id)) {
                 args <- list(x=x[id],
@@ -400,60 +401,88 @@ panel.superpose <-
 
 
 
-
-
-
-
-
-
-
-
-panel.superpose.2 <- 
-    function (x, y, subscripts, groups, col, col.line = superpose.line$col,
-              col.symbol = superpose.symbol$col, pch = superpose.symbol$pch,
-              cex = superpose.symbol$cex, lty = superpose.line$lty,
-              lwd = superpose.line$lwd, type="p", ...)
+panel.superpose.2 <-
+    function(x, y = NULL, subscripts, groups,
+             panel.groups = "panel.xyplot",
+             col,
+             col.line = superpose.line$col,
+             col.symbol = superpose.symbol$col,
+             pch = superpose.symbol$pch,
+             cex = superpose.symbol$cex, 
+             font = superpose.symbol$font, 
+             fontface = superpose.symbol$fontface, 
+             fontfamily = superpose.symbol$fontfamily, 
+             lty = superpose.line$lty,
+             lwd = superpose.line$lwd,
+             type = "p",
+             ...)
 {
-    
-    ##   `panel.superpose.2' :  This is a version of the 'panel.superpose'
-    ##   Trellis panel function that allows the plot `type' to change between
-    ##   superimposed (overlayed) data sets.  See the `panel.xyplot' function
-    ##   for details on the `type' option which is usually a single character,
-    ##   but here is a character vector with each element specifying the
-    ##   plot style of each subsequently-overlayed plot.
-    ##                        ---  Neil Klepeis, 26-Dec-2001
-    
-    x <- as.numeric(x)
-    y <- as.numeric(y)
 
-    if (length(x) > 0) {
-        if (!missing(col)) {
-            if (missing(col.line))
-                col.line <- col
-            if (missing(col.symbol))
-                col.symbol <- col
+    ## This is a (very) slightly different version of panel.superpose.
+    ## It has an explicit type argument which behaves like other
+    ## graphical parameters, i.e., it is repeated to be as long as the
+    ## number of groups, and one used for each group.  This is the
+    ## default behaviour of panel.superpose in S-PLUS.
+
+    ## Original version contributed by Neil Klepeis
+
+    type <- as.list(type)
+
+    x <- as.numeric(x)
+    if (!is.null(y)) y <- as.numeric(y)
+
+    if (length(x)>0)
+    {
+        if (!missing(col))
+        {
+            if (missing(col.line)) col.line <- col
+            if (missing(col.symbol)) col.symbol <- col
         }
+
         superpose.symbol <- trellis.par.get("superpose.symbol")
         superpose.line <- trellis.par.get("superpose.line")
-        x <- as.numeric(x)
-        y <- as.numeric(y)
+
         vals <-
             if (is.factor(groups)) levels(groups)
             else sort(unique(groups))
         nvals <- length(vals)
-        col.line <- rep(col.line, length = nvals)
-        col.symbol <- rep(col.symbol, length = nvals)
-        pch <- rep(pch, length = nvals)
-        lty <- rep(lty, length = nvals)
-        lwd <- rep(lwd, length = nvals)
-        cex <- rep(cex, length = nvals)
-        type <- rep(type, length = nvals)      # new line here
-        for (i in seq(along = vals)) {
+        col.line <- rep(col.line, length=nvals)
+        col.symbol <- rep(col.symbol, length=nvals)
+        pch <- rep(pch, length=nvals)
+        lty <- rep(lty, length=nvals)
+        lwd <- rep(lwd, length=nvals)
+        cex <- rep(cex, length=nvals)
+        font <- rep(font, length=nvals)
+        fontface <- rep(fontface, length=nvals)
+        fontfamily <- rep(fontfamily, length=nvals)
+        type <- rep(type, length=nvals)
+
+        panel.groups <- 
+            if (is.function(panel.groups)) panel.groups
+            else if (is.character(panel.groups)) get(panel.groups)
+            else eval(panel.groups)
+
+        for (i in seq(along=vals))
+        {
             id <- (groups[subscripts] == vals[i])
             if (any(id))
-                panel.xyplot(x = x[id], y = y[id], pch = pch[i],
-                  cex = cex[i], col.line = col.line[i], col.symbol = col.symbol[i],
-                  lty = lty[i], lwd = lwd[i], type=type[i], ...)
+            {
+                args <- list(x=x[id],
+                             groups = groups,
+                             subscripts = subscripts[id],
+                             pch = pch[i], cex = cex[i],
+                             font = font[i],
+                             fontface = fontface[i],
+                             fontfamily = fontfamily[i],
+                             col.line = col.line[i],
+                             col.symbol = col.symbol[i],
+                             lty = lty[i],
+                             lwd = lwd[i],
+                             type = type[[i]], ...)
+                if (!is.null(y)) args$y <- y[id]
+
+                do.call("panel.groups", args)
+            }
         }
     }
 }
@@ -462,6 +491,64 @@ panel.superpose.2 <-
 
 
 
+# panel.superpose.2 <- 
+#     function(x, y, subscripts, groups,
+#              col, col.line = superpose.line$col,
+#              col.symbol = superpose.symbol$col,
+#              pch = superpose.symbol$pch,
+#              cex = superpose.symbol$cex,
+#              lty = superpose.line$lty,
+#              lwd = superpose.line$lwd, type="p", ...)
+# {
+    
+#     ## `panel.superpose.2' : This is a version of the
+#     ## 'panel.superpose' Trellis panel function that allows the plot
+#     ## `type' to change between superimposed (overlayed) data sets.
+#     ## See the `panel.xyplot' function for details on the `type'
+#     ## option which is usually a single character, but here is a
+#     ## character vector with each element specifying the plot style of
+#     ## each subsequently-overlayed plot.  --- Neil Klepeis,
+#     ## 26-Dec-2001
+    
+#     x <- as.numeric(x)
+#     y <- as.numeric(y)
+
+#     if (length(x) > 0) {
+#         if (!missing(col)) {
+#             if (missing(col.line))
+#                 col.line <- col
+#             if (missing(col.symbol))
+#                 col.symbol <- col
+#         }
+#         superpose.symbol <- trellis.par.get("superpose.symbol")
+#         superpose.line <- trellis.par.get("superpose.line")
+#         x <- as.numeric(x)
+#         y <- as.numeric(y)
+#         vals <-
+#             if (is.factor(groups)) levels(groups)
+#             else sort(unique(groups))
+#         nvals <- length(vals)
+#         col.line <- rep(col.line, length = nvals)
+#         col.symbol <- rep(col.symbol, length = nvals)
+#         pch <- rep(pch, length = nvals)
+#         lty <- rep(lty, length = nvals)
+#         lwd <- rep(lwd, length = nvals)
+#         cex <- rep(cex, length = nvals)
+#         type <- rep(type, length = nvals)      # new line here
+#         for (i in seq(along = vals)) {
+#             id <- (groups[subscripts] == vals[i])
+#             if (any(id))
+#                 panel.xyplot(x = x[id], y = y[id], pch = pch[i],
+#                   cex = cex[i], col.line = col.line[i], col.symbol = col.symbol[i],
+#                   lty = lty[i], lwd = lwd[i], type=type[i], ...)
+#         }
+#     }
+# }
+
+
+
+
+
 
 
 panel.linejoin <-
@@ -521,47 +608,3 @@ panel.mathdensity <-
 }
 
 
-
-getTextPosition <- function(x, y)
-    ## returns position 1: below, 2: left, 3: above, 4: right (w.r.t
-    ## origin)
-{
-    a <- abs(c(x, y))
-    if (y <= 0 && a[1] <= -y) 1
-    else if (x <= 0 && a[2] <= -x) 2
-    else if (y >= 0 && a[1] <= y) 3
-    else if (x >= 0 && a[2] <= x) 4
-}
-
-
-panel.identify <-
-    function (x, y = NULL, labels = seq(along = x), 
-              n = length(x), offset = 0.5,
-              threshold = 18, ## in points, roughly 0.25 inches
-              ...)
-    ## ... goes to ltext
-{
-    xy <- xy.coords(x, y)
-    x <- xy$x
-    y <- xy$y
-    px <- convertX(unit(x, "native"), "points", TRUE)
-    py <- convertY(unit(y, "native"), "points", TRUE)
-    labels <- as.character(labels)
-    for (i in seq(length = n))
-    {
-        ll <- grid.locator(unit = "points")
-        if (convertX(ll$x, "npc", TRUE) < 0.0001) break ## need to do better
-        lx <- convertX(ll$x, "points", TRUE)
-        ly <- convertY(ll$y, "points", TRUE)
-        pdists <- sqrt((px - lx)^2 + (py - ly)^2)
-        if (min(pdists, na.rm = TRUE) > threshold)
-            warning("no points within threshold of ", threshold, " points")
-        else {
-            w <- which.min(pdists)
-            pos <- getTextPosition(x = lx - px[w], y = ly - py[w])
-            ltext(x[w], y[w], labels[w], pos = pos, offset = offset, ...)
-        }
-    }
-}
-
-
