@@ -645,14 +645,25 @@ lattice.options <- function(...)
     if (is.null(nm)) return(old[unlist(new)]) ## typically getting opions, not setting
     isNamed <- nm != "" ## typically all named when setting, but could have mix
     if (any(!isNamed)) nm[!isNamed] <- unlist(new[!isNamed])
+
     ## so now everything has non-"" names, but only the isNamed ones should be set
     ## everything should be returned, however
 
     retVal <- old[nm]
     names(retVal) <- nm
     nm <- nm[isNamed]
-    modified <- updateList(retVal[nm], new[nm])
-    .LatticeEnv$lattice.options[names(modified)] <- modified
+
+    ## this used to be 
+
+    ## modified <- updateList(retVal[nm], new[nm])
+    ## .LatticeEnv$lattice.options[names(modified)] <- modified
+
+    ## but then calling lattice.options(foo = NULL) had no effect
+    ## because foo would be missing from modified.  So, we now do:
+
+    .LatticeEnv$lattice.options <- updateList(old, new[nm])
+
+    ## return changed entries invisibly
     invisible(retVal)
 }
 
